# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: location.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import commonroad.scenario_definition.protobuf_format.generated_scripts.util_pb2 as util__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='location.proto',
  package='commonroad',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0elocation.proto\x12\ncommonroad\x1a\nutil.proto\"=\n\rTimeOfDayEnum\",\n\tTimeOfDay\x12\t\n\x05NIGHT\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\"l\n\x0bWeatherEnum\"]\n\x07Weather\x12\t\n\x05SUNNY\x10\x00\x12\x0e\n\nLIGHT_RAIN\x10\x01\x12\r\n\tHEAVY_AIN\x10\x02\x12\x07\n\x03\x46OG\x10\x03\x12\x08\n\x04SNOW\x10\x04\x12\x08\n\x04HAIL\x10\x05\x12\x0b\n\x07UNKNOWN\x10\x06\"l\n\x0fUndergroundEnum\"Y\n\x0bUnderground\x12\x07\n\x03WET\x10\x00\x12\t\n\x05\x43LEAN\x10\x01\x12\t\n\x05\x44IRTY\x10\x02\x12\x0b\n\x07\x44\x41MAGED\x10\x03\x12\x08\n\x04SNOW\x10\x04\x12\x07\n\x03ICE\x10\x05\x12\x0b\n\x07UNKNOWN\x10\x06\"}\n\x11GeoTransformation\x12\x15\n\rgeo_reference\x18\x01 \x01(\t\x12\x15\n\rx_translation\x18\x02 \x01(\x01\x12\x15\n\ry_translation\x18\x03 \x01(\x01\x12\x12\n\nz_rotation\x18\x04 \x01(\x01\x12\x0f\n\x07scaling\x18\x05 \x01(\x01\"\xdc\x01\n\x0b\x45nvironment\x12#\n\x04time\x18\x01 \x01(\x0b\x32\x15.commonroad.TimeStamp\x12\x38\n\x0btime_of_day\x18\x02 \x01(\x0e\x32#.commonroad.TimeOfDayEnum.TimeOfDay\x12\x30\n\x07weather\x18\x03 \x01(\x0e\x32\x1f.commonroad.WeatherEnum.Weather\x12<\n\x0bunderground\x18\x04 \x01(\x0e\x32\'.commonroad.UndergroundEnum.Underground\"\xb5\x01\n\x08Location\x12\x13\n\x0bgeo_name_id\x18\x01 \x02(\x05\x12\x14\n\x0cgps_latitude\x18\x02 \x02(\x01\x12\x15\n\rgps_longitude\x18\x03 \x02(\x01\x12\x39\n\x12geo_transformation\x18\x04 \x01(\x0b\x32\x1d.commonroad.GeoTransformation\x12,\n\x0b\x65nvironment\x18\x05 \x01(\x0b\x32\x17.commonroad.Environment'
  ,
  dependencies=[util__pb2.DESCRIPTOR,])



_TIMEOFDAYENUM_TIMEOFDAY = _descriptor.EnumDescriptor(
  name='TimeOfDay',
  full_name='commonroad.TimeOfDayEnum.TimeOfDay',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=59,
  serialized_end=103,
)
_sym_db.RegisterEnumDescriptor(_TIMEOFDAYENUM_TIMEOFDAY)

_WEATHERENUM_WEATHER = _descriptor.EnumDescriptor(
  name='Weather',
  full_name='commonroad.WeatherEnum.Weather',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUNNY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHT_RAIN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEAVY_AIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAIL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=120,
  serialized_end=213,
)
_sym_db.RegisterEnumDescriptor(_WEATHERENUM_WEATHER)

_UNDERGROUNDENUM_UNDERGROUND = _descriptor.EnumDescriptor(
  name='Underground',
  full_name='commonroad.UndergroundEnum.Underground',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRTY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAMAGED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=234,
  serialized_end=323,
)
_sym_db.RegisterEnumDescriptor(_UNDERGROUNDENUM_UNDERGROUND)


_TIMEOFDAYENUM = _descriptor.Descriptor(
  name='TimeOfDayEnum',
  full_name='commonroad.TimeOfDayEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TIMEOFDAYENUM_TIMEOFDAY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=103,
)


_WEATHERENUM = _descriptor.Descriptor(
  name='WeatherEnum',
  full_name='commonroad.WeatherEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WEATHERENUM_WEATHER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=213,
)


_UNDERGROUNDENUM = _descriptor.Descriptor(
  name='UndergroundEnum',
  full_name='commonroad.UndergroundEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UNDERGROUNDENUM_UNDERGROUND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=323,
)


_GEOTRANSFORMATION = _descriptor.Descriptor(
  name='GeoTransformation',
  full_name='commonroad.GeoTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_reference', full_name='commonroad.GeoTransformation.geo_reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_translation', full_name='commonroad.GeoTransformation.x_translation', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_translation', full_name='commonroad.GeoTransformation.y_translation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z_rotation', full_name='commonroad.GeoTransformation.z_rotation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaling', full_name='commonroad.GeoTransformation.scaling', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=450,
)


_ENVIRONMENT = _descriptor.Descriptor(
  name='Environment',
  full_name='commonroad.Environment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='commonroad.Environment.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_of_day', full_name='commonroad.Environment.time_of_day', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weather', full_name='commonroad.Environment.weather', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underground', full_name='commonroad.Environment.underground', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=673,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='commonroad.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_name_id', full_name='commonroad.Location.geo_name_id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_latitude', full_name='commonroad.Location.gps_latitude', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_longitude', full_name='commonroad.Location.gps_longitude', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_transformation', full_name='commonroad.Location.geo_transformation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='commonroad.Location.environment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=857,
)

_TIMEOFDAYENUM_TIMEOFDAY.containing_type = _TIMEOFDAYENUM
_WEATHERENUM_WEATHER.containing_type = _WEATHERENUM
_UNDERGROUNDENUM_UNDERGROUND.containing_type = _UNDERGROUNDENUM
_ENVIRONMENT.fields_by_name['time'].message_type = util__pb2._TIMESTAMP
_ENVIRONMENT.fields_by_name['time_of_day'].enum_type = _TIMEOFDAYENUM_TIMEOFDAY
_ENVIRONMENT.fields_by_name['weather'].enum_type = _WEATHERENUM_WEATHER
_ENVIRONMENT.fields_by_name['underground'].enum_type = _UNDERGROUNDENUM_UNDERGROUND
_LOCATION.fields_by_name['geo_transformation'].message_type = _GEOTRANSFORMATION
_LOCATION.fields_by_name['environment'].message_type = _ENVIRONMENT
DESCRIPTOR.message_types_by_name['TimeOfDayEnum'] = _TIMEOFDAYENUM
DESCRIPTOR.message_types_by_name['WeatherEnum'] = _WEATHERENUM
DESCRIPTOR.message_types_by_name['UndergroundEnum'] = _UNDERGROUNDENUM
DESCRIPTOR.message_types_by_name['GeoTransformation'] = _GEOTRANSFORMATION
DESCRIPTOR.message_types_by_name['Environment'] = _ENVIRONMENT
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeOfDayEnum = _reflection.GeneratedProtocolMessageType('TimeOfDayEnum', (_message.Message,), {
  'DESCRIPTOR' : _TIMEOFDAYENUM,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TimeOfDayEnum)
  })
_sym_db.RegisterMessage(TimeOfDayEnum)

WeatherEnum = _reflection.GeneratedProtocolMessageType('WeatherEnum', (_message.Message,), {
  'DESCRIPTOR' : _WEATHERENUM,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.WeatherEnum)
  })
_sym_db.RegisterMessage(WeatherEnum)

UndergroundEnum = _reflection.GeneratedProtocolMessageType('UndergroundEnum', (_message.Message,), {
  'DESCRIPTOR' : _UNDERGROUNDENUM,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.UndergroundEnum)
  })
_sym_db.RegisterMessage(UndergroundEnum)

GeoTransformation = _reflection.GeneratedProtocolMessageType('GeoTransformation', (_message.Message,), {
  'DESCRIPTOR' : _GEOTRANSFORMATION,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.GeoTransformation)
  })
_sym_db.RegisterMessage(GeoTransformation)

Environment = _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENT,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Environment)
  })
_sym_db.RegisterMessage(Environment)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'location_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Location)
  })
_sym_db.RegisterMessage(Location)


# @@protoc_insertion_point(module_scope)



import enum
from typing import Set

import numpy as np

from commonroad.common.validity import *
import commonroad.geometry.transform


class RoadUser(enum.Enum):
    """
    Enum describing different types of road users
    """
    VEHICLE = 'vehicle'
    CAR = 'car'
    TRUCK = 'truck'
    BUS = 'bus'
    PRIORITY_VEHICLE = 'priorityVehicle'
    MOTORCYCLE = 'motorcycle'
    BICYCLE = 'bicycle'
    PEDESTRIAN = 'pedestrian'
    TRAIN = 'train'
    TAXI = 'taxi'


class LineMarking(enum.Enum):
    """
    Enum describing different types of line markings, i.e. dashed or solid lines
    """
    DASHED = 'dashed'
    SOLID = 'solid'
    BROAD_DASHED = 'broad_dashed'
    BROAD_SOLID = 'broad_solid'
    UNKNOWN = 'unknown'
    NO_MARKING = 'no_marking'


class LaneletType(enum.Enum):
    """
    Enum describing different types of lanelets
    """
    URBAN = 'urban'
    COUNTRY = 'country'
    HIGHWAY = 'highway'
    DRIVE_WAY = 'driveWay'
    MAIN_CARRIAGE_WAY = 'mainCarriageWay'
    ACCESS_RAMP = 'accessRamp'
    EXIT_RAMP = 'exitRamp'
    SHOULDER = 'shoulder'
    BUS_LANE = 'busLane'
    BUS_STOP = 'busStop'
    BICYCLE_LANE = 'bicycleLane'
    SIDEWALK = 'sidewalk'
    CROSSWALK = 'crosswalk'
    INTERSTATE = 'interstate'
    INTERSECTION = 'intersection'
    BORDER = 'border'
    PARKING = 'parking'
    RESTRICTED = 'restricted'  # cars not allowed, e.g., special lanes for busses
    UNKNOWN = 'unknown'


class StopLine:
    """Class which describes the stop line of a lanelet"""

    def __init__(self, start: np.ndarray, end: np.ndarray, line_marking: LineMarking, traffic_sign_ref: Set[int] = None,
                 traffic_light_ref: Set[int] = None):
        self._start = start
        self._end = end
        self._line_marking = line_marking
        self._traffic_sign_ref = traffic_sign_ref
        self._traffic_light_ref = traffic_light_ref

    def __eq__(self, other):
        if not isinstance(other, StopLine):
            warnings.warn(f"Inequality between StopLine {repr(self)} and different type {type(other)}")
            return False

        prec = 10
        start_string = np.array2string(np.around(self._start.astype(float), prec), precision=prec)
        start_other_string = np.array2string(np.around(other.start.astype(float), prec), precision=prec)
        end_string = np.array2string(np.around(self._end.astype(float), prec), precision=prec)
        end_other_string = np.array2string(np.around(other.end.astype(float), prec), precision=prec)

        if start_string == start_other_string and end_string == end_other_string and self._line_marking == \
                other.line_marking and self._traffic_sign_ref == other.traffic_sign_ref and self._traffic_light_ref \
                == other.traffic_light_ref:
            return True

        warnings.warn(f"Inequality of StopLine {repr(self)} and the other one {repr(other)}")
        return False

    def __hash__(self):
        if self._start is None:
            start_string = None
        else:
            start_string = np.array2string(np.around(self._start.astype(float), 10), precision=10)
        if self._end is None:
            end_string = None
        else:
            end_string = np.array2string(np.around(self._end.astype(float), 10), precision=10)
        sign_ref = None if self._traffic_sign_ref is None else frozenset(self._traffic_sign_ref)
        light_ref = None if self._traffic_light_ref is None else frozenset(self._traffic_light_ref)
        return hash((start_string, end_string, self._line_marking, sign_ref, light_ref))

    def __str__(self):
        return f'StopLine from {self._start} to {self._end}'

    def __repr__(self):
        return f"StopLine(start={self._start.tolist()}, end={self._end.tolist()}, line_marking={self._line_marking}, " \
               f"traffic_sign_ref={self._traffic_sign_ref}, traffic_light_ref={self._traffic_light_ref})"

    @property
    def start(self) -> np.ndarray:
        return self._start

    @start.setter
    def start(self, value: np.ndarray):
        self._start = value

    @property
    def end(self) -> np.ndarray:
        return self._end

    @end.setter
    def end(self, value: np.ndarray):
        self._end = value

    @property
    def line_marking(self) -> LineMarking:
        return self._line_marking

    @line_marking.setter
    def line_marking(self, marking: LineMarking):
        self._line_marking = marking

    @property
    def traffic_sign_ref(self) -> Set[int]:
        return self._traffic_sign_ref

    @traffic_sign_ref.setter
    def traffic_sign_ref(self, references: Set[int]):
        self._traffic_sign_ref = references

    @property
    def traffic_light_ref(self) -> Set[int]:
        return self._traffic_light_ref

    @traffic_light_ref.setter
    def traffic_light_ref(self, references: Set[int]):
        self._traffic_light_ref = references

    def translate_rotate(self, translation: np.ndarray, angle: float):
        """
        This method translates and rotates a stop line

        :param translation: The translation given as [x_off,y_off] for the x and y translation
        :param angle: The rotation angle in radian (counter-clockwise defined)
        """

        assert is_real_number_vector(translation, 2), '<Lanelet/translate_rotate>: provided translation ' \
                                                      'is not valid! translation = {}'.format(translation)
        assert is_valid_orientation(
                angle), '<Lanelet/translate_rotate>: provided angle is not valid! angle = {}'.format(angle)

        # create transformation matrix
        t_m = commonroad.geometry.transform.translation_rotation_matrix(translation, angle)
        line_vertices = np.array([self._start, self._end])
        # transform center vertices
        tmp = t_m.dot(np.vstack((line_vertices.transpose(), np.ones((1, line_vertices.shape[0])))))
        tmp = tmp[0:2, :].transpose()
        self._start, self._end = tmp[0], tmp[1]




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: phantom_obstacle.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import commonroad.scenario_definition.protobuf_format.generated_scripts.obstacle_pb2 as obstacle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='phantom_obstacle.proto',
  package='commonroad',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16phantom_obstacle.proto\x12\ncommonroad\x1a\x0eobstacle.proto\"Z\n\x0fPhantomObstacle\x12\x13\n\x0bobstacle_id\x18\x01 \x02(\r\x12\x32\n\nprediction\x18\x02 \x01(\x0b\x32\x1e.commonroad.SetBasedPrediction'
  ,
  dependencies=[obstacle__pb2.DESCRIPTOR,])




_PHANTOMOBSTACLE = _descriptor.Descriptor(
  name='PhantomObstacle',
  full_name='commonroad.PhantomObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='commonroad.PhantomObstacle.obstacle_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='commonroad.PhantomObstacle.prediction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=144,
)

_PHANTOMOBSTACLE.fields_by_name['prediction'].message_type = obstacle__pb2._SETBASEDPREDICTION
DESCRIPTOR.message_types_by_name['PhantomObstacle'] = _PHANTOMOBSTACLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PhantomObstacle = _reflection.GeneratedProtocolMessageType('PhantomObstacle', (_message.Message,), {
  'DESCRIPTOR' : _PHANTOMOBSTACLE,
  '__module__' : 'phantom_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.PhantomObstacle)
  })
_sym_db.RegisterMessage(PhantomObstacle)


# @@protoc_insertion_point(module_scope)



import enum
from typing import Set, List

import numpy as np

from commonroad.common.validity import is_valid_polyline
from commonroad.common.common_lanelet import LineMarking


class AreaType(enum.Enum):
    """
    Enum describing different types of an area
    """
    BUS_STOP = "bus_stop"
    BORDER = "border"
    PARKING = "parking"
    RESTRICTED = "restricted"
    UNKNOWN = "unknown"


class AreaBorder:
    """
    Class which describes a border of an area
    """
    def __init__(self, area_border_id: int, border_vertices: np.ndarray, adjacent: int = None,
                 line_marking: LineMarking = None):
        """
        Constructor of an AreaBorder object

        :param area_border_id: id of the area border
        :param border_vertices: array that contains the coordinates of the border's vertices
        :param adjacent: id of the lanelet adjacent to the border
        :param line_marking: line marking of the area border
        """
        self._area_border_id = area_border_id
        self._border_vertices = border_vertices
        self._adjacent = adjacent
        self._line_marking = line_marking

    @property
    def area_border_id(self) -> int:
        """ Id of the area border."""
        return self._area_border_id

    @area_border_id.setter
    def area_border_id(self, value: int):
        assert isinstance(value, int), '<AreaBorder/area_border_id>: Provided id is not valid! id={}'.format(value)
        self._area_border_id = value

    @property
    def border_vertices(self) -> np.ndarray:
        """ Array that contains the coordinates of the border's vertices."""
        return self._border_vertices

    @border_vertices.setter
    def border_vertices(self, value: np.ndarray):
        assert is_valid_polyline(value), '<AreaBorder/border_vertices>: The provided polyline ' \
                                            'is not valid! id = {} polyline = {}'.format(self._area_border_id, value)
        self._border_vertices = value

    @property
    def adjacent(self) -> int:
        """ Id of the lanelet adjacent to the border."""
        return self._adjacent

    @adjacent.setter
    def adjacent(self, val: int):
        assert isinstance(val, int), '<AreaBorder/adjacent>: Provided adjacent is not valid! adjacent={}'.format(val)
        self._adjacent = val

    @property
    def line_marking(self) -> LineMarking:
        """ Line marking of the area border."""
        return self._line_marking

    @line_marking.setter
    def line_marking(self, value: LineMarking):
        assert isinstance(value, LineMarking), '<AreaBorder/line_marking>: Provided lane marking type' \
                                               'is not valid! type = {}'.format(type(value))
        self._line_marking = value


class Area:
    """
    Class which describes an area
    """
    def __init__(self, area_id: int, border: List[AreaBorder] = None, area_types: Set[AreaType] = None):
        """
        Constructor of an Area object.

        :param area_id: id of the area
        :param border: list of area borders corresponding to the area
        :param area_types: set of area types corresponding to the area
        """
        self._area_id = area_id
        self._border = border
        self._area_types = area_types

    @property
    def area_id(self) -> int:
        """ Id of the area."""
        return self._area_id

    @area_id.setter
    def area_id(self, value: int):
        assert isinstance(value, int), '<Area/area_id>: Provided area_id is not valid! id={}'.format(value)
        self._area_id = value

    @property
    def border(self) -> List[AreaBorder]:
        """ List of area borders corresponding to the area."""
        return self._border

    @border.setter
    def border(self, value: List[AreaBorder]):
        assert isinstance(value, list), '<Area/border>: provided list of area borders is not a ' \
                                       'list! type = {}'.format(type(value))
        for val in value:
            assert isinstance(val, AreaBorder), '<Area/border>: Provided border list is not valid! id={}'.format(value)
        self._border = value

    @property
    def area_types(self) -> Set[AreaType]:
        """ Set of area types corresponding to the area."""
        return self._area_types

    @area_types.setter
    def area_types(self, value: Set[AreaType]):
        assert isinstance(value, set), '<Area/area_types>: provided set of area types is not a ' \
                                              'set! type = {}'.format(type(value))
        for val in value:
            assert isinstance(val, AreaType), '<Area/area_types>: Provided area type set is not valid! id={}'\
                .format(value)
        self._area_types = value



import datetime
import re
from typing import Set, Union, List
import logging

import numpy as np
from google.protobuf.message import DecodeError

from commonroad.common.util import Interval, FileFormat, Time
from commonroad.common.writer.file_writer_interface import FileWriter, OverwriteExistingFile
from commonroad.geometry.shape import Rectangle, Circle, Polygon, ShapeGroup, Shape
from commonroad.planning.planning_problem import PlanningProblemSet, PlanningProblem
from commonroad.prediction.prediction import Occupancy, TrajectoryPrediction, SetBasedPrediction
from commonroad.scenario_definition.protobuf_format.generated_scripts import commonroad_pb2, util_pb2, \
    phantom_obstacle_pb2
from commonroad.scenario_definition.protobuf_format.generated_scripts import lanelet_pb2, planning_problem_pb2, \
    traffic_sign_pb2, scenario_tags_pb2, environment_obstacle_pb2, obstacle_pb2, intersection_pb2, \
    dynamic_obstacle_pb2, static_obstacle_pb2, traffic_light_pb2, location_pb2
from commonroad.scenario.intersection import Intersection, IntersectionIncomingElement
from commonroad.scenario.lanelet import Lanelet
from commonroad.common.common_lanelet import StopLine, LineMarking
from commonroad.scenario.obstacle import StaticObstacle, DynamicObstacle, EnvironmentObstacle, SignalState, \
    PhantomObstacle
from commonroad.scenario.scenario import Scenario, Tag, Location, GeoTransformation, Environment
from commonroad.scenario.traffic_sign import TrafficSign, TrafficSignElement, \
    TrafficSignIDGermany, TrafficSignIDFrance, TrafficSignIDZamunda, TrafficSignIDUsa, TrafficSignIDChina, \
    TrafficSignIDSpain, TrafficSignIDRussia, TrafficSignIDArgentina, TrafficSignIDBelgium, TrafficSignIDGreece, \
    TrafficSignIDCroatia, TrafficSignIDItaly
from commonroad.scenario.traffic_light import TrafficLightCycleElement, TrafficLight
from commonroad.scenario.trajectory import Trajectory
from commonroad.scenario.state import State

logger = logging.getLogger(__name__)


class ProtobufFileWriter(FileWriter):
    """
    Writes CommonRoad files in protobuf format.
    """

    def __init__(self, scenario: Scenario, planning_problem_set: PlanningProblemSet, author: str = None,
                 affiliation: str = None, source: str = None, tags: Set[Tag] = None, location: Location = None,
                 decimal_precision: int = 4):
        super().__init__(scenario, planning_problem_set, author, affiliation, source, tags, location, decimal_precision)

        self._commonroad_msg = commonroad_pb2.CommonRoad()

    def _write_header(self):
        """
        Stores all information about scenario and planning problems as protobuf message.

        :return:
        """
        information_msg = ScenarioInformationMessage.create_message(self.scenario.scenario_id.scenario_version,
                                                                    str(self.scenario.scenario_id), self._author,
                                                                    self._affiliation, self._source, self.scenario.dt)

        self._commonroad_msg.information.CopyFrom(information_msg)

    def _add_all_objects_from_scenario(self):
        """
        Stores all scenario objects as protobuf message.

        :return:
        """
        scenario_tags = ScenarioTagsMessage.create_message(list(self.scenario.tags))
        self._commonroad_msg.scenario_tags.CopyFrom(scenario_tags)

        if self.location is not None:
            location_msg = LocationMessage.create_message(self.location)
        else:
            location_msg = LocationMessage.create_message(Location())
            logger.warning("Default location will be written to protobuf!")
        self._commonroad_msg.location.CopyFrom(location_msg)

        for lanelet in self.scenario.lanelet_network.lanelets:
            lanelet_msg = LaneletMessage.create_message(lanelet)
            self._commonroad_msg.lanelets.append(lanelet_msg)

        for traffic_sign in self.scenario.lanelet_network.traffic_signs:
            traffic_sign_msg = TrafficSignMessage.create_message(traffic_sign)
            self._commonroad_msg.traffic_signs.append(traffic_sign_msg)

        for traffic_light in self.scenario.lanelet_network.traffic_lights:
            traffic_light_msg = TrafficLightMessage.create_message(traffic_light)
            self._commonroad_msg.traffic_lights.append(traffic_light_msg)

        for intersection in self.scenario.lanelet_network.intersections:
            intersection_msg = IntersectionMessage.create_message(intersection)
            self._commonroad_msg.intersections.append(intersection_msg)

        for static_obstacle in self.scenario.static_obstacles:
            static_obstacle_msg = StaticObstacleMessage.create_message(static_obstacle)
            self._commonroad_msg.static_obstacles.append(static_obstacle_msg)

        for dynamic_obstacle in self.scenario.dynamic_obstacles:
            dynamic_obstacle_msg = DynamicObstacleMessage.create_message(dynamic_obstacle)
            self._commonroad_msg.dynamic_obstacles.append(dynamic_obstacle_msg)

        for environment_obstacle in self.scenario.environment_obstacle:
            environment_obstacle_msg = EnvironmentObstacleMessage.create_message(environment_obstacle)
            self._commonroad_msg.environment_obstacles.append(environment_obstacle_msg)

        for phantom_obstacle in self.scenario.phantom_obstacle:
            phantom_obstacle_msg = PhantomObstacleMessage.create_message(phantom_obstacle)
            self._commonroad_msg.phantom_obstacles.append(phantom_obstacle_msg)

    def _add_all_planning_problems_from_planning_problem_set(self):
        """
        Stores all planning problems as protobuf message.

        :return:
        """
        for planning_problem in self.planning_problem_set.planning_problem_dict.values():
            planning_problem_msg = PlanningProblemMessage.create_message(planning_problem)
            self._commonroad_msg.planning_problems.append(planning_problem_msg)

    def _serialize_write_msg(self, filename: str):
        """
        Serializes the message of type commonroad and writes into file.

        :param filename: Name of file
        :return:
        """
        with open(filename, "wb") as f:
            f.write(self._commonroad_msg.SerializeToString())

    def _get_suffix(self) -> str:
        return FileFormat.PROTOBUF.value

    def write_to_file(self, filename: Union[str, None] = None,
                      overwrite_existing_file: OverwriteExistingFile = OverwriteExistingFile.ASK_USER_INPUT,
                      check_validity: bool = False):
        """
        Writes message of type commonroad into file.

        :param filename: Name of file
        :param overwrite_existing_file: Mode of writing
        :param check_validity: Validity checking before writing
        :return:
        """
        filename = self._handle_file_path(filename, overwrite_existing_file)
        if not filename:
            return

        self._commonroad_msg = commonroad_pb2.CommonRoad()

        self._write_header()
        self._add_all_objects_from_scenario()
        self._add_all_planning_problems_from_planning_problem_set()

        if check_validity:
            pass

        self._serialize_write_msg(filename)

    def write_scenario_to_file(self, filename: Union[str, None] = None,
                               overwrite_existing_file: OverwriteExistingFile = OverwriteExistingFile.ASK_USER_INPUT):
        """
        Writes scenario as protobuf message into file.

        :param filename: Name of file
        :param overwrite_existing_file: Mode of writing
        :return:
        """
        filename = self._handle_file_path(filename, overwrite_existing_file)
        if not filename:
            return

        self._commonroad_msg = commonroad_pb2.CommonRoad()

        self._write_header()
        self._add_all_objects_from_scenario()

        self._serialize_write_msg(filename)

    @staticmethod
    def check_validity_of_commonroad_file(commonroad_str: Union[str, bytes]) -> bool:
        """
        Checks validity of CommonRoad message/file.

        :param commonroad_str: Commonroad instance in form of binary string
        :return: Valid or not
        """
        try:
            commonroad_msg = commonroad_pb2.CommonRoad()
            commonroad_msg.ParseFromString(commonroad_str)
            return True
        except DecodeError:
            return False


class ScenarioInformationMessage:

    @classmethod
    def create_message(cls, commonroad_version: str, benchmark_id: str, author: str, affiliation: str, source: str,
                       time_step_size: float) -> commonroad_pb2.ScenarioInformation:
        scenario_information_msg = commonroad_pb2.ScenarioInformation()
        scenario_information_msg.common_road_version = commonroad_version
        scenario_information_msg.benchmark_id = benchmark_id
        time_stamp_msg = TimeStampMessage.create_message(datetime.datetime.today())
        scenario_information_msg.date.CopyFrom(time_stamp_msg)
        scenario_information_msg.author = author
        scenario_information_msg.affiliation = affiliation
        scenario_information_msg.source = source
        scenario_information_msg.time_step_size = time_step_size

        return scenario_information_msg


class ScenarioTagsMessage:

    @classmethod
    def create_message(cls, tags: List[Tag]) -> scenario_tags_pb2.ScenarioTags:
        scenario_tags_msg = scenario_tags_pb2.ScenarioTags()

        for tag in tags:
            scenario_tags_msg.tags.append(scenario_tags_pb2.TagEnum.Tag.Value(tag.name))

        return scenario_tags_msg


class LocationMessage:

    @classmethod
    def create_message(cls, location: Location) -> location_pb2.Location:
        location_msg = location_pb2.Location()

        location_msg.geo_name_id = location.geo_name_id
        location_msg.gps_latitude = location.gps_latitude
        location_msg.gps_longitude = location.gps_longitude

        if location.geo_transformation is not None:
            geo_transformation_msg = GeoTransformationMessage.create_message(location.geo_transformation)
            location_msg.geo_transformation.CopyFrom(geo_transformation_msg)
        if location.environment is not None:
            environment_msg = EnvironmentMessage.create_message(location.environment)
            location_msg.environment.CopyFrom(environment_msg)

        return location_msg


class GeoTransformationMessage:

    @classmethod
    def create_message(cls, geo_transformation: GeoTransformation) -> location_pb2.GeoTransformation:
        geo_transformation_msg = location_pb2.GeoTransformation()

        geo_transformation_msg.geo_reference = geo_transformation.geo_reference
        geo_transformation_msg.x_translation = geo_transformation.x_translation
        geo_transformation_msg.y_translation = geo_transformation.y_translation
        geo_transformation_msg.z_rotation = geo_transformation.z_rotation
        geo_transformation_msg.scaling = geo_transformation.scaling

        return geo_transformation_msg


class EnvironmentMessage:

    @classmethod
    def create_message(cls, environment: Environment) -> location_pb2.Environment:
        environment_msg = location_pb2.Environment()

        if environment.time is not None:
            time_stamp_msg = TimeStampMessage.create_message(environment.time)
            environment_msg.time.CopyFrom(time_stamp_msg)
        if environment.time_of_day is not None:
            environment_msg.time_of_day = location_pb2.TimeOfDayEnum.TimeOfDay.Value(environment.time_of_day.name)
        if environment.weather is not None:
            environment_msg.weather = location_pb2.WeatherEnum.Weather.Value(environment.weather.name)
        if environment.underground is not None:
            environment_msg.underground = location_pb2.UndergroundEnum.Underground.Value(environment.underground.name)

        return environment_msg


class LaneletMessage:

    @classmethod
    def create_message(cls, lanelet: Lanelet) -> lanelet_pb2.Lanelet:
        lanelet_msg = lanelet_pb2.Lanelet()

        lanelet_msg.lanelet_id = lanelet.lanelet_id

        bound_msg = BoundMessage.create_message(lanelet.left_vertices, lanelet.line_marking_left_vertices)
        lanelet_msg.left_bound.CopyFrom(bound_msg)

        bound_msg = BoundMessage.create_message(lanelet.right_vertices, lanelet.line_marking_right_vertices)
        lanelet_msg.right_bound.CopyFrom(bound_msg)

        for pre in lanelet.predecessor:
            lanelet_msg.predecessors.append(pre)

        for suc in lanelet.successor:
            lanelet_msg.successors.append(suc)

        if lanelet.adj_left is not None:
            lanelet_msg.adjacent_left = lanelet.adj_left

        if lanelet.adj_right is not None:
            lanelet_msg.adjacent_right = lanelet.adj_right

        if lanelet.adj_left_same_direction is not None:
            if lanelet.adj_left_same_direction:
                lanelet_msg.adjacent_left_dir = lanelet_pb2.DrivingDirEnum.DrivingDir.Value('SAME')
            else:
                lanelet_msg.adjacent_left_dir = lanelet_pb2.DrivingDirEnum.DrivingDir.Value('OPPOSITE')

        if lanelet.adj_right_same_direction is not None:
            if lanelet.adj_right_same_direction:
                lanelet_msg.adjacent_right_dir = lanelet_pb2.DrivingDirEnum.DrivingDir.Value('SAME')
            else:
                lanelet_msg.adjacent_right_dir = lanelet_pb2.DrivingDirEnum.DrivingDir.Value('OPPOSITE')

        if lanelet.stop_line is not None:
            stop_line_msg = StopLineMessage.create_message(lanelet.stop_line)
            lanelet_msg.stop_line.CopyFrom(stop_line_msg)

        for lanelet_type in lanelet.lanelet_type:
            lanelet_msg.lanelet_types.append(lanelet_pb2.LaneletTypeEnum.LaneletType.Value(lanelet_type.name))

        for user_one_way in lanelet.user_one_way:
            lanelet_msg.user_one_way.append(lanelet_pb2.RoadUserEnum.RoadUser.Value(user_one_way.name))

        for user_bidirectional in lanelet.user_bidirectional:
            lanelet_msg.user_bidirectional.append(lanelet_pb2.RoadUserEnum.RoadUser.Value(user_bidirectional.name))

        for ts_ref in lanelet.traffic_signs:
            lanelet_msg.traffic_sign_refs.append(ts_ref)

        for tl_ref in lanelet.traffic_lights:
            lanelet_msg.traffic_light_refs.append(tl_ref)

        return lanelet_msg


class BoundMessage:

    @classmethod
    def create_message(cls, vertices: np.ndarray, line_marking: LineMarking) -> lanelet_pb2.Bound:
        bound_msg = lanelet_pb2.Bound()

        for vertex in vertices:
            point_msg = PointMessage.create_message(vertex)
            bound_msg.points.append(point_msg)

        if line_marking is not None:
            bound_msg.line_marking = lanelet_pb2.LineMarkingEnum.LineMarking.Value(line_marking.name)

        return bound_msg


class StopLineMessage:

    @classmethod
    def create_message(cls, stop_line: StopLine) -> lanelet_pb2.StopLine:
        stop_line_msg = lanelet_pb2.StopLine()

        if stop_line.start is not None:
            point_msg = PointMessage.create_message(stop_line.start)
            stop_line_msg.points.append(point_msg)

        if stop_line.end is not None:
            point_msg = PointMessage.create_message(stop_line.end)
            stop_line_msg.points.append(point_msg)

        stop_line_msg.line_marking = lanelet_pb2.LineMarkingEnum.LineMarking.Value(stop_line.line_marking.name)

        if stop_line.traffic_sign_ref is not None:
            for ts_ref in stop_line.traffic_sign_ref:
                stop_line_msg.traffic_sign_refs.append(ts_ref)

        if stop_line.traffic_light_ref is not None:
            for tl_ref in stop_line.traffic_light_ref:
                stop_line_msg.traffic_light_refs.append(tl_ref)

        return stop_line_msg


class TrafficSignMessage:

    @classmethod
    def create_message(cls, traffic_sign: TrafficSign) -> traffic_sign_pb2.TrafficSign:
        traffic_sign_msg = traffic_sign_pb2.TrafficSign()

        traffic_sign_msg.traffic_sign_id = traffic_sign.traffic_sign_id

        for traffic_sign_element in traffic_sign.traffic_sign_elements:
            traffic_sign_element_msg = TrafficSignElementMessage.create_message(traffic_sign_element)
            traffic_sign_msg.traffic_sign_elements.append(traffic_sign_element_msg)

        if traffic_sign.position is not None:
            point_msg = PointMessage.create_message(traffic_sign.position)
            traffic_sign_msg.position.CopyFrom(point_msg)

        if traffic_sign.virtual is not None:
            traffic_sign_msg.virtual = traffic_sign.virtual

        return traffic_sign_msg


class TrafficSignElementMessage:

    @classmethod
    def create_message(cls, traffic_sign_element: TrafficSignElement) -> traffic_sign_pb2.TrafficSignElement:
        traffic_sign_element_msg = traffic_sign_pb2.TrafficSignElement()

        element_id = traffic_sign_element.traffic_sign_element_id
        if isinstance(element_id, TrafficSignIDGermany):
            traffic_sign_element_msg.germany_element_id = traffic_sign_pb2.TrafficSignIDGermanyEnum \
                .TrafficSignIDGermany.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDZamunda):
            traffic_sign_element_msg.zamunda_element_id = traffic_sign_pb2.TrafficSignIDZamundaEnum \
                .TrafficSignIDZamunda.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDUsa):
            traffic_sign_element_msg.usa_element_id = traffic_sign_pb2.TrafficSignIDUsaEnum \
                .TrafficSignIDUsa.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDChina):
            traffic_sign_element_msg.china_element_id = traffic_sign_pb2.TrafficSignIDChinaEnum \
                .TrafficSignIDChina.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDSpain):
            traffic_sign_element_msg.spain_element_id = traffic_sign_pb2.TrafficSignIDSpainEnum \
                .TrafficSignIDSpain.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDRussia):
            traffic_sign_element_msg.russia_element_id = traffic_sign_pb2.TrafficSignIDRussiaEnum \
                .TrafficSignIDRussia.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDArgentina):
            traffic_sign_element_msg.argentina_element_id = traffic_sign_pb2.TrafficSignIDArgentinaEnum \
                .TrafficSignIDArgentina.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDBelgium):
            traffic_sign_element_msg.belgium_element_id = traffic_sign_pb2.TrafficSignIDBelgiumEnum \
                .TrafficSignIDBelgium.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDFrance):
            traffic_sign_element_msg.france_element_id = traffic_sign_pb2.TrafficSignIDFranceEnum \
                .TrafficSignIDFrance.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDGreece):
            traffic_sign_element_msg.greece_element_id = traffic_sign_pb2.TrafficSignIDGreeceEnum \
                .TrafficSignIDGreece.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDCroatia):
            traffic_sign_element_msg.croatia_element_id = traffic_sign_pb2.TrafficSignIDCroatiaEnum \
                .TrafficSignIDCroatia.Value(element_id.name)
        elif isinstance(element_id, TrafficSignIDItaly):
            traffic_sign_element_msg.italy_element_id = traffic_sign_pb2.TrafficSignIDItalyEnum \
                .TrafficSignIDItaly.Value(element_id.name)
        else:
            traffic_sign_element_msg.puerto_rico_element_id = traffic_sign_pb2.TrafficSignIDPuertoRicoEnum \
                .TrafficSignIDPuertoRico.Value(element_id.name)

        for additional_value in traffic_sign_element.additional_values:
            traffic_sign_element_msg.additional_values.append(additional_value)

        return traffic_sign_element_msg


class TrafficLightMessage:

    @classmethod
    def create_message(cls, traffic_light: TrafficLight) -> traffic_light_pb2.TrafficLight:
        traffic_light_msg = traffic_light_pb2.TrafficLight()

        traffic_light_msg.traffic_light_id = traffic_light.traffic_light_id

        for cycle_element in traffic_light.traffic_light_cycle.cycle_elements:
            cycle_element_msg = CycleElementMessage.create_message(cycle_element)
            traffic_light_msg.cycle_elements.append(cycle_element_msg)

        if traffic_light.position is not None:
            point_msg = PointMessage.create_message(traffic_light.position)
            traffic_light_msg.position.CopyFrom(point_msg)

        if traffic_light.traffic_light_cycle.time_offset is not None:
            traffic_light_msg.time_offset = traffic_light.traffic_light_cycle.time_offset

        if traffic_light.direction is not None:
            traffic_light_msg.direction = traffic_light_pb2.TrafficLightDirectionEnum.TrafficLightDirection \
                .Value(traffic_light.direction.name)

        if traffic_light.active is not None:
            traffic_light_msg.active = traffic_light.active

        return traffic_light_msg


class CycleElementMessage:

    @classmethod
    def create_message(cls, cycle_element: TrafficLightCycleElement) -> traffic_light_pb2.CycleElement:
        cycle_element_msg = traffic_light_pb2.CycleElement()

        cycle_element_msg.duration = cycle_element.duration
        cycle_element_msg.color = traffic_light_pb2.TrafficLightStateEnum.TrafficLightState \
            .Value(cycle_element.state.name)

        return cycle_element_msg


class IntersectionMessage:

    @classmethod
    def create_message(cls, intersection: Intersection) -> intersection_pb2.Intersection:
        intersection_msg = intersection_pb2.Intersection()

        intersection_msg.intersection_id = intersection.intersection_id

        for incoming in intersection.incomings:
            incoming_msg = IncomingMessage.create_message(incoming)
            intersection_msg.incomings.append(incoming_msg)

        for crossing in intersection.crossings:
            intersection_msg.crossing_lanelets.append(crossing)

        return intersection_msg


class IncomingMessage:

    @classmethod
    def create_message(cls, incoming: IntersectionIncomingElement) -> intersection_pb2.Incoming:
        incoming_msg = intersection_pb2.Incoming()

        incoming_msg.incoming_id = incoming.incoming_id
        for incoming_lanelet in incoming.incoming_lanelets:
            incoming_msg.incoming_lanelets.append(incoming_lanelet)

        for successor_right in incoming.successors_right:
            incoming_msg.successors_right.append(successor_right)

        for successor_straight in incoming.successors_straight:
            incoming_msg.successors_straight.append(successor_straight)

        for successor_left in incoming.successors_left:
            incoming_msg.successors_left.append(successor_left)

        if incoming.left_of is not None:
            incoming_msg.is_left_of = incoming.left_of

        return incoming_msg


class StaticObstacleMessage:

    @classmethod
    def create_message(cls, static_obstacle: StaticObstacle) -> static_obstacle_pb2.StaticObstacle:
        static_obstacle_msg = static_obstacle_pb2.StaticObstacle()

        static_obstacle_msg.static_obstacle_id = static_obstacle.obstacle_id

        static_obstacle_msg.obstacle_type = obstacle_pb2.ObstacleTypeEnum.ObstacleType \
            .Value(static_obstacle.obstacle_type.name)

        shape_msg = ShapeMessage.create_message(static_obstacle.obstacle_shape)
        static_obstacle_msg.shape.CopyFrom(shape_msg)

        state_msg = StateMessage.create_message(static_obstacle.initial_state)
        static_obstacle_msg.initial_state.CopyFrom(state_msg)

        signal_state_msg = SignalStateMessage.create_message(static_obstacle.initial_signal_state)
        static_obstacle_msg.initial_signal_state.CopyFrom(signal_state_msg)

        for signal_state in static_obstacle.signal_series:
            signal_state_msg = SignalStateMessage.create_message(signal_state)
            static_obstacle_msg.signal_series.append(signal_state_msg)

        return static_obstacle_msg


class StateMessage:

    @classmethod
    def create_message(cls, state: State) -> obstacle_pb2.State:
        state_msg = obstacle_pb2.State()

        for attr in state.used_attributes:
            if getattr(state, attr) is None:
                continue

            if attr == 'position':
                if isinstance(state.position, np.ndarray):
                    state_msg.point.CopyFrom(PointMessage.create_message(state.position))
                else:
                    state_msg.shape.CopyFrom(ShapeMessage.create_message(state.position))
            elif attr == 'time_step':
                integer_exact_or_interval_msg = IntegerExactOrIntervalMessage.create_message(state.time_step)
                state_msg.time_step.CopyFrom(integer_exact_or_interval_msg)
            else:
                float_exact_or_interval_msg = FloatExactOrIntervalMessage.create_message(getattr(state, attr))
                getattr(state_msg, StateMessage._map_to_pb_prop(attr)).CopyFrom(float_exact_or_interval_msg)

        return state_msg

    @staticmethod
    def _map_to_pb_prop(prop: str) -> str:
        return re.sub('(?<!^)(?=[A-Z])', '_', prop).lower()


class SignalStateMessage:

    @classmethod
    def create_message(cls, signal_state: SignalState) -> obstacle_pb2.SignalState:
        signal_state_msg = obstacle_pb2.SignalState()

        for attr in SignalState.__slots__:
            if hasattr(signal_state, attr):
                if getattr(signal_state, attr) is None:
                    continue

                if attr == 'time_step':
                    integer_exact_or_interval_msg = IntegerExactOrIntervalMessage.create_message(signal_state.time_step)
                    signal_state_msg.time_step.CopyFrom(integer_exact_or_interval_msg)
                else:
                    setattr(signal_state_msg, attr, getattr(signal_state, attr))

        return signal_state_msg


class DynamicObstacleMessage:

    @classmethod
    def create_message(cls, dynamic_obstacle: DynamicObstacle) -> dynamic_obstacle_pb2.DynamicObstacle:
        dynamic_obstacle_msg = dynamic_obstacle_pb2.DynamicObstacle()

        dynamic_obstacle_msg.dynamic_obstacle_id = dynamic_obstacle.obstacle_id
        dynamic_obstacle_msg.obstacle_type = obstacle_pb2.ObstacleTypeEnum.ObstacleType \
            .Value(dynamic_obstacle.obstacle_type.name)

        shape_msg = ShapeMessage.create_message(dynamic_obstacle.obstacle_shape)
        dynamic_obstacle_msg.shape.CopyFrom(shape_msg)

        state_msg = StateMessage.create_message(dynamic_obstacle.initial_state)
        dynamic_obstacle_msg.initial_state.CopyFrom(state_msg)

        if isinstance(dynamic_obstacle.prediction, TrajectoryPrediction):
            trajectory_prediction_msg = TrajectoryPredictionMessage.create_message(dynamic_obstacle.prediction)
            dynamic_obstacle_msg.trajectory_prediction.CopyFrom(trajectory_prediction_msg)
        elif isinstance(dynamic_obstacle.prediction, SetBasedPrediction):
            set_based_prediction_msg = SetBasedPredictionMessage.create_message(dynamic_obstacle.prediction)
            dynamic_obstacle_msg.set_based_prediction.CopyFrom(set_based_prediction_msg)

        if dynamic_obstacle.initial_signal_state is not None:
            signal_state_msg = SignalStateMessage.create_message(dynamic_obstacle.initial_signal_state)
            dynamic_obstacle_msg.initial_signal_state.CopyFrom(signal_state_msg)

        if dynamic_obstacle.signal_series is not None:
            for signal_state in dynamic_obstacle.signal_series:
                signal_state_msg = SignalStateMessage.create_message(signal_state)
                dynamic_obstacle_msg.signal_series.append(signal_state_msg)

        return dynamic_obstacle_msg


class TrajectoryMessage:

    @classmethod
    def create_message(cls, trajectory: Trajectory) -> obstacle_pb2.Trajectory:
        trajectory_msg = obstacle_pb2.Trajectory()

        trajectory_msg.initial_time_step = trajectory.initial_time_step

        for state in trajectory.state_list:
            state_msg = StateMessage.create_message(state)
            trajectory_msg.states.append(state_msg)

        return trajectory_msg


class OccupancySetMessage:

    @classmethod
    def create_message(cls, occupancy_set: List[Occupancy]) -> obstacle_pb2.OccupancySet:
        occupancy_set_msg = obstacle_pb2.OccupancySet()

        for occupancy in occupancy_set:
            occupancy_msg = OccupancyMessage.create_message(occupancy)
            occupancy_set_msg.occupancies.append(occupancy_msg)

        return occupancy_set_msg


class OccupancyMessage:

    @classmethod
    def create_message(cls, occupancy: Occupancy) -> obstacle_pb2.Occupancy:
        occupancy_msg = obstacle_pb2.Occupancy()

        integer_exact_or_interval_msg = IntegerExactOrIntervalMessage.create_message(occupancy.time_step)
        occupancy_msg.time_step.CopyFrom(integer_exact_or_interval_msg)

        shape_msg = ShapeMessage.create_message(occupancy.shape)
        occupancy_msg.shape.CopyFrom(shape_msg)

        return occupancy_msg


class TrajectoryPredictionMessage:

    @classmethod
    def create_message(cls, trajectory_prediction: TrajectoryPrediction) -> obstacle_pb2.TrajectoryPrediction:
        trajectory_prediction_msg = obstacle_pb2.TrajectoryPrediction()

        trajectory_msg = TrajectoryMessage.create_message(trajectory_prediction.trajectory)
        trajectory_prediction_msg.trajectory.CopyFrom(trajectory_msg)

        shape_msg = ShapeMessage.create_message(trajectory_prediction.shape)
        trajectory_prediction_msg.shape.CopyFrom(shape_msg)

        return trajectory_prediction_msg


class SetBasedPredictionMessage:

    @classmethod
    def create_message(cls, set_based_prediction: SetBasedPrediction) -> obstacle_pb2.SetBasedPrediction:
        set_based_prediction_msg = obstacle_pb2.SetBasedPrediction()

        set_based_prediction_msg.initial_time_step = set_based_prediction.initial_time_step

        occupancy_set_msg = OccupancySetMessage.create_message(set_based_prediction.occupancy_set)
        set_based_prediction_msg.occupancy_set.CopyFrom(occupancy_set_msg)

        return set_based_prediction_msg


class EnvironmentObstacleMessage:

    @classmethod
    def create_message(cls, environment_obstacle: EnvironmentObstacle) -> environment_obstacle_pb2.EnvironmentObstacle:
        environment_obstacle_msg = environment_obstacle_pb2.EnvironmentObstacle()

        environment_obstacle_msg.environment_obstacle_id = environment_obstacle.obstacle_id
        environment_obstacle_msg.obstacle_type = obstacle_pb2.ObstacleTypeEnum.ObstacleType \
            .Value(environment_obstacle.obstacle_type.name)

        shape_msg = ShapeMessage.create_message(environment_obstacle.obstacle_shape)
        environment_obstacle_msg.obstacle_shape.CopyFrom(shape_msg)

        return environment_obstacle_msg


class PhantomObstacleMessage:

    @classmethod
    def create_message(cls, phantom_obstacle: PhantomObstacle) -> phantom_obstacle_pb2.PhantomObstacle:
        phantom_obstacle_msg = phantom_obstacle_pb2.PhantomObstacle()

        phantom_obstacle_msg.obstacle_id = phantom_obstacle.obstacle_id

        if phantom_obstacle.prediction is not None:
            set_based_prediction_msg = SetBasedPredictionMessage.create_message(phantom_obstacle.prediction)
            phantom_obstacle_msg.prediction.CopyFrom(set_based_prediction_msg)

        return phantom_obstacle_msg


class PlanningProblemMessage:

    @classmethod
    def create_message(cls, planning_problem: PlanningProblem) -> planning_problem_pb2.PlanningProblem:
        planning_problem_msg = planning_problem_pb2.PlanningProblem()

        planning_problem_msg.planning_problem_id = planning_problem.planning_problem_id

        state_msg = StateMessage.create_message(planning_problem.initial_state)
        planning_problem_msg.initial_state.CopyFrom(state_msg)

        for i, state in enumerate(planning_problem.goal.state_list):
            if planning_problem.goal.lanelets_of_goal_position is not None:
                goal_state_msg = GoalStateMessage \
                    .create_message(state, planning_problem.goal.lanelets_of_goal_position[i])
            else:
                goal_state_msg = GoalStateMessage.create_message(state, list())
            planning_problem_msg.goal_states.append(goal_state_msg)

        return planning_problem_msg


class GoalStateMessage:

    @classmethod
    def create_message(cls, state: State, lanelets_of_goal_position: List[int]) -> planning_problem_pb2.GoalState:
        goal_state_msg = planning_problem_pb2.GoalState()

        state_msg = StateMessage.create_message(state)
        goal_state_msg.state.CopyFrom(state_msg)

        for lanelet_id in lanelets_of_goal_position:
            goal_state_msg.goal_position_lanelets.append(lanelet_id)

        return goal_state_msg


class PointMessage:

    @classmethod
    def create_message(cls, point: np.ndarray) -> util_pb2.Point:
        point_msg = util_pb2.Point()

        point_msg.x = point[0]
        point_msg.y = point[1]

        return point_msg


class ShapeMessage:

    @classmethod
    def create_message(cls, shape: Shape) -> util_pb2.Shape:
        shape_msg = util_pb2.Shape()

        if isinstance(shape, Rectangle):
            shape_msg.rectangle.CopyFrom(RectangleMessage.create_message(shape))
        elif isinstance(shape, Circle):
            shape_msg.circle.CopyFrom(CircleMessage.create_message(shape))
        elif isinstance(shape, Polygon):
            shape_msg.polygon.CopyFrom(PolygonMessage.create_message(shape))
        elif isinstance(shape, ShapeGroup):
            shape_msg.shape_group.CopyFrom(ShapeGroupMessage.create_message(shape))

        return shape_msg


class RectangleMessage:

    @classmethod
    def create_message(cls, rectangle: Rectangle) -> util_pb2.Rectangle:
        rectangle_msg = util_pb2.Rectangle()

        rectangle_msg.length = rectangle.length
        rectangle_msg.width = rectangle.width

        if rectangle.center is not None:
            point_msg = PointMessage.create_message(rectangle.center)
            rectangle_msg.center.CopyFrom(point_msg)

        if rectangle.orientation is not None:
            rectangle_msg.orientation = rectangle.orientation

        return rectangle_msg


class CircleMessage:

    @classmethod
    def create_message(cls, circle: Circle) -> util_pb2.Circle:
        circle_msg = util_pb2.Circle()

        circle_msg.radius = circle.radius

        if circle.center is not None:
            point_msg = PointMessage.create_message(circle.center)
            circle_msg.center.CopyFrom(point_msg)

        return circle_msg


class PolygonMessage:

    @classmethod
    def create_message(cls, polygon: Polygon) -> util_pb2.Polygon:
        polygon_msg = util_pb2.Polygon()

        for vertex in polygon.vertices:
            point_msg = PointMessage.create_message(vertex)
            polygon_msg.vertices.append(point_msg)

        return polygon_msg


class ShapeGroupMessage:

    @classmethod
    def create_message(cls, shape_group: ShapeGroup) -> util_pb2.ShapeGroup:
        shape_group_msg = util_pb2.ShapeGroup()

        for shape in shape_group.shapes:
            shape_msg = ShapeMessage.create_message(shape)
            shape_group_msg.shapes.append(shape_msg)

        return shape_group_msg


class IntegerIntervalMessage:

    @classmethod
    def create_message(cls, interval: Interval) -> util_pb2.IntegerInterval:
        integer_interval_msg = util_pb2.IntegerInterval()

        integer_interval_msg.start = interval.start
        integer_interval_msg.end = interval.end

        return integer_interval_msg


class FloatIntervalMessage:

    @classmethod
    def create_message(cls, interval: Interval) -> util_pb2.FloatInterval:
        float_interval_msg = util_pb2.FloatInterval()

        float_interval_msg.start = interval.start
        float_interval_msg.end = interval.end

        return float_interval_msg


class IntegerExactOrIntervalMessage:

    @classmethod
    def create_message(cls, value: Union[int, Interval]) -> util_pb2.IntegerExactOrInterval:
        integer_exact_or_interval_msg = util_pb2.IntegerExactOrInterval()

        if isinstance(value, int):
            integer_exact_or_interval_msg.exact = value
        else:
            integer_interval_msg = IntegerIntervalMessage.create_message(value)
            integer_exact_or_interval_msg.interval.CopyFrom(integer_interval_msg)

        return integer_exact_or_interval_msg


class FloatExactOrIntervalMessage:

    @classmethod
    def create_message(cls, value: Union[int, Interval]) -> util_pb2.FloatExactOrInterval:
        float_exact_or_interval_msg = util_pb2.FloatExactOrInterval()

        if isinstance(value, float) or isinstance(value, int):
            float_exact_or_interval_msg.exact = value
        else:
            float_interval_msg = FloatIntervalMessage.create_message(value)
            float_exact_or_interval_msg.interval.CopyFrom(float_interval_msg)

        return float_exact_or_interval_msg


class IntegerListMessage:

    @classmethod
    def create_message(cls, values: List[int]) -> util_pb2.IntegerList:
        integer_list_msg = util_pb2.IntegerList()

        for value in values:
            integer_list_msg.values.append(value)

        return integer_list_msg


class FloatListMessage:

    @classmethod
    def create_message(cls, values: List[float]) -> util_pb2.FloatList:
        float_list_msg = util_pb2.FloatList()

        for value in values:
            float_list_msg.values.append(value)

        return float_list_msg


class TimeStampMessage:

    @classmethod
    def create_message(cls, time_stamp: Union[datetime.datetime, Time]):
        time_stamp_msg = util_pb2.TimeStamp()

        if isinstance(time_stamp, datetime.datetime):
            time_stamp_msg.year = time_stamp.year
            time_stamp_msg.month = time_stamp.month
            time_stamp_msg.day = time_stamp.day
            time_stamp_msg.hour = time_stamp.hour
            time_stamp_msg.minute = time_stamp.minute
        else:
            time_stamp_msg.hour = time_stamp.hours
            time_stamp_msg.minute = time_stamp.minutes

        return time_stamp_msg



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: static_obstacle.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import commonroad.scenario_definition.protobuf_format.generated_scripts.obstacle_pb2 as obstacle__pb2
import commonroad.scenario_definition.protobuf_format.generated_scripts.util_pb2 as util__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='static_obstacle.proto',
  package='commonroad',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15static_obstacle.proto\x12\ncommonroad\x1a\x0eobstacle.proto\x1a\nutil.proto\"\xa1\x02\n\x0eStaticObstacle\x12\x1a\n\x12static_obstacle_id\x18\x01 \x02(\r\x12@\n\robstacle_type\x18\x02 \x02(\x0e\x32).commonroad.ObstacleTypeEnum.ObstacleType\x12 \n\x05shape\x18\x03 \x02(\x0b\x32\x11.commonroad.Shape\x12(\n\rinitial_state\x18\x04 \x02(\x0b\x32\x11.commonroad.State\x12\x35\n\x14initial_signal_state\x18\x05 \x01(\x0b\x32\x17.commonroad.SignalState\x12.\n\rsignal_series\x18\x06 \x03(\x0b\x32\x17.commonroad.SignalState'
  ,
  dependencies=[obstacle__pb2.DESCRIPTOR,util__pb2.DESCRIPTOR,])




_STATICOBSTACLE = _descriptor.Descriptor(
  name='StaticObstacle',
  full_name='commonroad.StaticObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_obstacle_id', full_name='commonroad.StaticObstacle.static_obstacle_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_type', full_name='commonroad.StaticObstacle.obstacle_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='commonroad.StaticObstacle.shape', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_state', full_name='commonroad.StaticObstacle.initial_state', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_signal_state', full_name='commonroad.StaticObstacle.initial_signal_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_series', full_name='commonroad.StaticObstacle.signal_series', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=355,
)

_STATICOBSTACLE.fields_by_name['obstacle_type'].enum_type = obstacle__pb2._OBSTACLETYPEENUM_OBSTACLETYPE
_STATICOBSTACLE.fields_by_name['shape'].message_type = util__pb2._SHAPE
_STATICOBSTACLE.fields_by_name['initial_state'].message_type = obstacle__pb2._STATE
_STATICOBSTACLE.fields_by_name['initial_signal_state'].message_type = obstacle__pb2._SIGNALSTATE
_STATICOBSTACLE.fields_by_name['signal_series'].message_type = obstacle__pb2._SIGNALSTATE
DESCRIPTOR.message_types_by_name['StaticObstacle'] = _STATICOBSTACLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StaticObstacle = _reflection.GeneratedProtocolMessageType('StaticObstacle', (_message.Message,), {
  'DESCRIPTOR' : _STATICOBSTACLE,
  '__module__' : 'static_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.StaticObstacle)
  })
_sym_db.RegisterMessage(StaticObstacle)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: util.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='util.proto',
  package='commonroad',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nutil.proto\x12\ncommonroad\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"b\n\tRectangle\x12\x0e\n\x06length\x18\x01 \x02(\x01\x12\r\n\x05width\x18\x02 \x02(\x01\x12!\n\x06\x63\x65nter\x18\x03 \x01(\x0b\x32\x11.commonroad.Point\x12\x13\n\x0borientation\x18\x04 \x01(\x01\";\n\x06\x43ircle\x12\x0e\n\x06radius\x18\x01 \x02(\x01\x12!\n\x06\x63\x65nter\x18\x02 \x01(\x0b\x32\x11.commonroad.Point\".\n\x07Polygon\x12#\n\x08vertices\x18\x01 \x03(\x0b\x32\x11.commonroad.Point\"/\n\nShapeGroup\x12!\n\x06shapes\x18\x01 \x03(\x0b\x32\x11.commonroad.Shape\"\xb9\x01\n\x05Shape\x12*\n\trectangle\x18\x01 \x01(\x0b\x32\x15.commonroad.RectangleH\x00\x12$\n\x06\x63ircle\x18\x02 \x01(\x0b\x32\x12.commonroad.CircleH\x00\x12&\n\x07polygon\x18\x03 \x01(\x0b\x32\x13.commonroad.PolygonH\x00\x12-\n\x0bshape_group\x18\x04 \x01(\x0b\x32\x16.commonroad.ShapeGroupH\x00\x42\x07\n\x05shape\"-\n\x0fIntegerInterval\x12\r\n\x05start\x18\x01 \x02(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x02(\x05\"+\n\rFloatInterval\x12\r\n\x05start\x18\x01 \x02(\x01\x12\x0b\n\x03\x65nd\x18\x02 \x02(\x01\"o\n\x16IntegerExactOrInterval\x12\x0f\n\x05\x65xact\x18\x01 \x01(\x05H\x00\x12/\n\x08interval\x18\x02 \x01(\x0b\x32\x1b.commonroad.IntegerIntervalH\x00\x42\x13\n\x11\x65xact_or_interval\"k\n\x14\x46loatExactOrInterval\x12\x0f\n\x05\x65xact\x18\x01 \x01(\x01H\x00\x12-\n\x08interval\x18\x02 \x01(\x0b\x32\x19.commonroad.FloatIntervalH\x00\x42\x13\n\x11\x65xact_or_interval\"\x1d\n\x0bIntegerList\x12\x0e\n\x06values\x18\x01 \x03(\x05\"\x1b\n\tFloatList\x12\x0e\n\x06values\x18\x01 \x03(\x05\"S\n\tTimeStamp\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\r\n\x05month\x18\x02 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\r\x12\x0c\n\x04hour\x18\x04 \x01(\r\x12\x0e\n\x06minute\x18\x05 \x01(\r'
)




_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='commonroad.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='commonroad.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='commonroad.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=55,
)


_RECTANGLE = _descriptor.Descriptor(
  name='Rectangle',
  full_name='commonroad.Rectangle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='commonroad.Rectangle.length', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='commonroad.Rectangle.width', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='commonroad.Rectangle.center', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='commonroad.Rectangle.orientation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=155,
)


_CIRCLE = _descriptor.Descriptor(
  name='Circle',
  full_name='commonroad.Circle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='commonroad.Circle.radius', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='commonroad.Circle.center', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=216,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='commonroad.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='commonroad.Polygon.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=264,
)


_SHAPEGROUP = _descriptor.Descriptor(
  name='ShapeGroup',
  full_name='commonroad.ShapeGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shapes', full_name='commonroad.ShapeGroup.shapes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=313,
)


_SHAPE = _descriptor.Descriptor(
  name='Shape',
  full_name='commonroad.Shape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rectangle', full_name='commonroad.Shape.rectangle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='circle', full_name='commonroad.Shape.circle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='commonroad.Shape.polygon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape_group', full_name='commonroad.Shape.shape_group', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='shape', full_name='commonroad.Shape.shape',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=316,
  serialized_end=501,
)


_INTEGERINTERVAL = _descriptor.Descriptor(
  name='IntegerInterval',
  full_name='commonroad.IntegerInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='commonroad.IntegerInterval.start', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='commonroad.IntegerInterval.end', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=548,
)


_FLOATINTERVAL = _descriptor.Descriptor(
  name='FloatInterval',
  full_name='commonroad.FloatInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='commonroad.FloatInterval.start', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='commonroad.FloatInterval.end', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=593,
)


_INTEGEREXACTORINTERVAL = _descriptor.Descriptor(
  name='IntegerExactOrInterval',
  full_name='commonroad.IntegerExactOrInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact', full_name='commonroad.IntegerExactOrInterval.exact', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='commonroad.IntegerExactOrInterval.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='exact_or_interval', full_name='commonroad.IntegerExactOrInterval.exact_or_interval',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=595,
  serialized_end=706,
)


_FLOATEXACTORINTERVAL = _descriptor.Descriptor(
  name='FloatExactOrInterval',
  full_name='commonroad.FloatExactOrInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact', full_name='commonroad.FloatExactOrInterval.exact', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='commonroad.FloatExactOrInterval.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='exact_or_interval', full_name='commonroad.FloatExactOrInterval.exact_or_interval',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=708,
  serialized_end=815,
)


_INTEGERLIST = _descriptor.Descriptor(
  name='IntegerList',
  full_name='commonroad.IntegerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='commonroad.IntegerList.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=846,
)


_FLOATLIST = _descriptor.Descriptor(
  name='FloatList',
  full_name='commonroad.FloatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='commonroad.FloatList.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=875,
)


_TIMESTAMP = _descriptor.Descriptor(
  name='TimeStamp',
  full_name='commonroad.TimeStamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='commonroad.TimeStamp.year', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='commonroad.TimeStamp.month', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='commonroad.TimeStamp.day', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='commonroad.TimeStamp.hour', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='commonroad.TimeStamp.minute', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=960,
)

_RECTANGLE.fields_by_name['center'].message_type = _POINT
_CIRCLE.fields_by_name['center'].message_type = _POINT
_POLYGON.fields_by_name['vertices'].message_type = _POINT
_SHAPEGROUP.fields_by_name['shapes'].message_type = _SHAPE
_SHAPE.fields_by_name['rectangle'].message_type = _RECTANGLE
_SHAPE.fields_by_name['circle'].message_type = _CIRCLE
_SHAPE.fields_by_name['polygon'].message_type = _POLYGON
_SHAPE.fields_by_name['shape_group'].message_type = _SHAPEGROUP
_SHAPE.oneofs_by_name['shape'].fields.append(
  _SHAPE.fields_by_name['rectangle'])
_SHAPE.fields_by_name['rectangle'].containing_oneof = _SHAPE.oneofs_by_name['shape']
_SHAPE.oneofs_by_name['shape'].fields.append(
  _SHAPE.fields_by_name['circle'])
_SHAPE.fields_by_name['circle'].containing_oneof = _SHAPE.oneofs_by_name['shape']
_SHAPE.oneofs_by_name['shape'].fields.append(
  _SHAPE.fields_by_name['polygon'])
_SHAPE.fields_by_name['polygon'].containing_oneof = _SHAPE.oneofs_by_name['shape']
_SHAPE.oneofs_by_name['shape'].fields.append(
  _SHAPE.fields_by_name['shape_group'])
_SHAPE.fields_by_name['shape_group'].containing_oneof = _SHAPE.oneofs_by_name['shape']
_INTEGEREXACTORINTERVAL.fields_by_name['interval'].message_type = _INTEGERINTERVAL
_INTEGEREXACTORINTERVAL.oneofs_by_name['exact_or_interval'].fields.append(
  _INTEGEREXACTORINTERVAL.fields_by_name['exact'])
_INTEGEREXACTORINTERVAL.fields_by_name['exact'].containing_oneof = _INTEGEREXACTORINTERVAL.oneofs_by_name['exact_or_interval']
_INTEGEREXACTORINTERVAL.oneofs_by_name['exact_or_interval'].fields.append(
  _INTEGEREXACTORINTERVAL.fields_by_name['interval'])
_INTEGEREXACTORINTERVAL.fields_by_name['interval'].containing_oneof = _INTEGEREXACTORINTERVAL.oneofs_by_name['exact_or_interval']
_FLOATEXACTORINTERVAL.fields_by_name['interval'].message_type = _FLOATINTERVAL
_FLOATEXACTORINTERVAL.oneofs_by_name['exact_or_interval'].fields.append(
  _FLOATEXACTORINTERVAL.fields_by_name['exact'])
_FLOATEXACTORINTERVAL.fields_by_name['exact'].containing_oneof = _FLOATEXACTORINTERVAL.oneofs_by_name['exact_or_interval']
_FLOATEXACTORINTERVAL.oneofs_by_name['exact_or_interval'].fields.append(
  _FLOATEXACTORINTERVAL.fields_by_name['interval'])
_FLOATEXACTORINTERVAL.fields_by_name['interval'].containing_oneof = _FLOATEXACTORINTERVAL.oneofs_by_name['exact_or_interval']
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['Rectangle'] = _RECTANGLE
DESCRIPTOR.message_types_by_name['Circle'] = _CIRCLE
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['ShapeGroup'] = _SHAPEGROUP
DESCRIPTOR.message_types_by_name['Shape'] = _SHAPE
DESCRIPTOR.message_types_by_name['IntegerInterval'] = _INTEGERINTERVAL
DESCRIPTOR.message_types_by_name['FloatInterval'] = _FLOATINTERVAL
DESCRIPTOR.message_types_by_name['IntegerExactOrInterval'] = _INTEGEREXACTORINTERVAL
DESCRIPTOR.message_types_by_name['FloatExactOrInterval'] = _FLOATEXACTORINTERVAL
DESCRIPTOR.message_types_by_name['IntegerList'] = _INTEGERLIST
DESCRIPTOR.message_types_by_name['FloatList'] = _FLOATLIST
DESCRIPTOR.message_types_by_name['TimeStamp'] = _TIMESTAMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Point)
  })
_sym_db.RegisterMessage(Point)

Rectangle = _reflection.GeneratedProtocolMessageType('Rectangle', (_message.Message,), {
  'DESCRIPTOR' : _RECTANGLE,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Rectangle)
  })
_sym_db.RegisterMessage(Rectangle)

Circle = _reflection.GeneratedProtocolMessageType('Circle', (_message.Message,), {
  'DESCRIPTOR' : _CIRCLE,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Circle)
  })
_sym_db.RegisterMessage(Circle)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Polygon)
  })
_sym_db.RegisterMessage(Polygon)

ShapeGroup = _reflection.GeneratedProtocolMessageType('ShapeGroup', (_message.Message,), {
  'DESCRIPTOR' : _SHAPEGROUP,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.ShapeGroup)
  })
_sym_db.RegisterMessage(ShapeGroup)

Shape = _reflection.GeneratedProtocolMessageType('Shape', (_message.Message,), {
  'DESCRIPTOR' : _SHAPE,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.Shape)
  })
_sym_db.RegisterMessage(Shape)

IntegerInterval = _reflection.GeneratedProtocolMessageType('IntegerInterval', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERINTERVAL,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.IntegerInterval)
  })
_sym_db.RegisterMessage(IntegerInterval)

FloatInterval = _reflection.GeneratedProtocolMessageType('FloatInterval', (_message.Message,), {
  'DESCRIPTOR' : _FLOATINTERVAL,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.FloatInterval)
  })
_sym_db.RegisterMessage(FloatInterval)

IntegerExactOrInterval = _reflection.GeneratedProtocolMessageType('IntegerExactOrInterval', (_message.Message,), {
  'DESCRIPTOR' : _INTEGEREXACTORINTERVAL,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.IntegerExactOrInterval)
  })
_sym_db.RegisterMessage(IntegerExactOrInterval)

FloatExactOrInterval = _reflection.GeneratedProtocolMessageType('FloatExactOrInterval', (_message.Message,), {
  'DESCRIPTOR' : _FLOATEXACTORINTERVAL,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.FloatExactOrInterval)
  })
_sym_db.RegisterMessage(FloatExactOrInterval)

IntegerList = _reflection.GeneratedProtocolMessageType('IntegerList', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERLIST,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.IntegerList)
  })
_sym_db.RegisterMessage(IntegerList)

FloatList = _reflection.GeneratedProtocolMessageType('FloatList', (_message.Message,), {
  'DESCRIPTOR' : _FLOATLIST,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.FloatList)
  })
_sym_db.RegisterMessage(FloatList)

TimeStamp = _reflection.GeneratedProtocolMessageType('TimeStamp', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMP,
  '__module__' : 'util_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TimeStamp)
  })
_sym_db.RegisterMessage(TimeStamp)


# @@protoc_insertion_point(module_scope)
